Class: RuboCop::Cop::Chef::Deprecations::UsesChefRESTHelpers
- Defined in:
- lib/rubocop/cop/chef/deprecation/chef_rest.rb
Overview
The Chef::REST class was removed in Chef Infra Client 13.
Constant Summary collapse
- MSG =
"Don't use the helpers in Chef::REST which were removed in Chef Infra Client 13"- RESTRICT_ON_SEND =
[:require].freeze
Instance Method Summary collapse
Methods inherited from Base
Instance Method Details
#on_const(node) ⇒ Object
51 52 53 54 55 |
# File 'lib/rubocop/cop/chef/deprecation/chef_rest.rb', line 51 def on_const(node) rest_const?(node) do add_offense(node, severity: :warning) end end |
#on_send(node) ⇒ Object
45 46 47 48 49 |
# File 'lib/rubocop/cop/chef/deprecation/chef_rest.rb', line 45 def on_send(node) require_rest?(node) do add_offense(node, severity: :warning) end end |