Class: RuboCop::Cop::Registry
- Inherits:
-
Object
- Object
- RuboCop::Cop::Registry
- Defined in:
- lib/rubocop/monkey_patches/registry_cop.rb
Instance Method Summary collapse
-
#print_department_missing_warning(name, path) ⇒ Object
we monkeypatch this warning to replace rubocop with cookstyle.
Instance Method Details
#print_department_missing_warning(name, path) ⇒ Object
we monkeypatch this warning to replace rubocop with cookstyle
6 7 8 9 10 |
# File 'lib/rubocop/monkey_patches/registry_cop.rb', line 6 def print_department_missing_warning(name, path) = "no department given for #{name}." += ' Run `cookstyle -a --only Migration/DepartmentName` to fix.' if path.end_with?('.rb') emit_warning(path, ) end |